..
  Copyright (c) Ansible Project
  GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
  SPDX-License-Identifier: GPL-3.0-or-later

********
Overview
********

The build process of Ansible using antsibull is described in the `ansible-build-data repository <https://github.com/ansible-community/ansible-build-data/>`_'s documentation:

* `How to release a new version of the Ansible Community Package — Manual Release Process <https://ansible.readthedocs.io/projects/ansible-build-data/release-process/>`_
* `How to release a new version of the Ansible Community Package — Automated Release Process <https://ansible.readthedocs.io/projects/ansible-build-data/automated-process/>`_

The sources for that documentation can be found `in the docs directory in the ansible-build-data repository <https://github.com/ansible-community/ansible-build-data/tree/main/docs>`_.
